@@ -24,8 +24,8 @@ experimental data an labels ordered as follows:
 -------------------------------------------------------------------------------------
 """
 
-__version__ = "1.3.1"
-__author__ = 'María M. Zanardi & Ariel M. Sarotti'
+__version__ = "1.3.2"
+__author__ = 'Ariel M. Sarotti & María M. Zanardi'
 
 import glob
 import pickle
